package com.muimi.kaburobo;

import java.net.URL;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Path;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Status;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The main plugin class to be used in the desktop.
 */
public class KaburoboPlugin extends AbstractUIPlugin {
    //The shared instance.
    private static KaburoboPlugin plugin;

    //Resource bundle.
    private ResourceBundle resourceBundle;

    public final static String PREF_KEY_KABUROBO_HOME = "kaburobo.home";

    public final static String STRING_VAR_KEY_KABUROBO_HOME = "kaburobo_home";
    
    public final static String KABUROBO_HOME_CLASSPATH_VARIABLE = "KABUROBO_HOME";

    /**
     * The constructor.
     */
    public KaburoboPlugin() {
        super();
        plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.muimi.kaburobo.KaburoboPluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
    }

    /**
     * This method is called upon plug-in activation
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * Returns the shared instance.
     */
    public static KaburoboPlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the string from the plugin's resource bundle, or 'key' if not
     * found.
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = KaburoboPlugin.getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * Returns the plugin's resource bundle,
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }


    public String getKaburoboHomePath(){
        return getPreferenceStore().getString(PREF_KEY_KABUROBO_HOME);
    }
    
	    

    public void updateKaburoboClasspathVariable() {
        try {
            String kaburoboHome = getPreferenceStore().getString(PREF_KEY_KABUROBO_HOME);
            JavaCore.setClasspathVariable(KABUROBO_HOME_CLASSPATH_VARIABLE,
                    new Path(kaburoboHome), null);
        } catch (JavaModelException e) {
            logError("", e);
        }
    }

    
	public static String getFilePath(String path) {
		try {			
			URL baseUrl = getDefault().getDescriptor().getInstallURL();
			URL resourceUrl = new URL(baseUrl, path);
			String resourcePath = Platform.asLocalURL(resourceUrl).getPath();
			return resourcePath;
		} catch (Exception e) {
			logError("fail to read resource. path=" + path, e);
			return null;
		}
	}
    
	public static void logError(String message, Throwable e){
		IStatus status = new Status(
						Status.ERROR,
						getDefault().getDescriptor().getUniqueIdentifier(),
						0,
						message,
						e
				);
		log(status);
	}
	
	public static void logInfo(String message){
		IStatus status = new Status(
						Status.INFO,
						getDefault().getDescriptor().getUniqueIdentifier(),
						0,
						message,
						null
				);
		log(status);
	}
	

	
	
	public static void log(IStatus status){
		getDefault().getLog().log(status);
	}
}